@@ -89,7 +89,7 @@ query_cache_entry_free (gpointer data)
         QueryCacheEntry *entry = data;
 
 #ifdef QUERY_CACHE_DEBUG
-        g_warning ("Blowing item %p", entry);
+        g_message ("Blowing item %p", entry);
 #endif /* QUERY_CACHE_DEBUG */
 
         g_free (entry->query);
@@ -185,6 +185,8 @@ query_cache_lookup (const char   *query,
 
         BONOBO_ACTIVATION_LOCK ();
 
+        *active = FALSE;
+
 	if (!query_cache) {
                 create_query_cache ();
                 BONOBO_ACTIVATION_UNLOCK ();
@@ -195,18 +197,17 @@ query_cache_lookup (const char   *query,
                 *active = TRUE;
                 return NULL;
         }
-        *active = FALSE;
 
 	fake.query = (char *) query;
 	fake.sort_criteria = (char **) sort_criteria;
 	if ((entry = g_hash_table_lookup (query_cache, &fake))) {
 #ifdef QUERY_CACHE_DEBUG
-		g_warning ("\n\n ---  Hit (%p)  ---\n\n\n", entry->list);
+		g_message ("\n\n ---  Hit (%p)  ---\n\n\n", entry->list);
 #endif /* QUERY_CACHE_DEBUG */
 		result = Bonobo_ServerInfoList_duplicate (entry->list);
 	} else {
 #ifdef QUERY_CACHE_DEBUG
-		g_warning ("Miss");
+		g_message ("Miss");
 #endif /* QUERY_CACHE_DEBUG */
 		result = NULL;
 	}
@@ -239,7 +240,7 @@ query_cache_insert (const char   *query,
 	g_hash_table_replace (query_cache, entry, entry);
 
 #ifdef QUERY_CACHE_DEBUG
-	g_warning ("Query cache size now %d",
+	g_message ("Query cache size now %d",
                 g_hash_table_size (query_cache));
 #endif /* QUERY_CACHE_DEBUG */
 }
@@ -382,9 +383,9 @@ bonobo_activation_activate (const char             *requirements,
                  bonobo_activation_context_get (), ev);
         
         if (ev->_major == CORBA_SYSTEM_EXCEPTION &&
-            !strcmp (ev->_id, ex_CORBA_NO_IMPLEMENT)) /* fall-back */
+            !strcmp (ev->_id, ex_CORBA_BAD_OPERATION)) /* fall-back */
         {
-                g_warning ("TESTME: Fall-back activate");
+                g_message ("TESTME: Fall-back activate");
                 result = Bonobo_ActivationContext_activateMatching
                         (ac, requirements, &selorder, &activation_environment,
                          flags, bonobo_activation_context_get (), ev);
@@ -457,7 +458,7 @@ bonobo_activation_activate_from_id (const Bonobo_ActivationID aid,
                  bonobo_activation_context_get (), ev);
 
         if (ev->_major == CORBA_SYSTEM_EXCEPTION &&
-            !strcmp (ev->_id, ex_CORBA_NO_IMPLEMENT)) /* fall-back */
+            !strcmp (ev->_id, ex_CORBA_BAD_OPERATION)) /* fall-back */
                 result = Bonobo_ActivationContext_activateFromAid
                         (ac, aid, flags, bonobo_activation_context_get (), ev);
 
