@@ -19,7 +19,7 @@ enum SIGNALS {
 
 enum PROPERTIES {
 	PROP_0,
-	PROP_NAME,
+	PROP_NAME
 };
 
 static guint signals [LAST_SIGNAL] = { 0 };
@@ -221,7 +221,7 @@ impl_Bonobo_Application_newInstance (PortableServer_Servant           servant,
 	return retval;
 }
 
-static __inline__ void
+static inline void
 message_desc_copy (Bonobo_Application_MessageDesc *dest,
 		   Bonobo_Application_MessageDesc *src)
 {
@@ -371,7 +371,7 @@ bonobo_application_init (BonoboApplication *self)
 BONOBO_TYPE_FUNC_FULL (BonoboApplication,
 		       Bonobo_Application,
 		       BONOBO_TYPE_OBJECT,
-		       bonobo_application);
+		       bonobo_application)
 
 
 /**
@@ -396,7 +396,7 @@ bonobo_application_new (const char *name)
 	return app;
 }
 
-static __inline__ CORBA_TypeCode
+static inline CORBA_TypeCode
 _gtype_to_typecode (GType gtype)
 {
 	static GHashTable *hash = NULL;
@@ -524,12 +524,7 @@ bonobo_application_register_message_va (BonoboApplication *app,
  * @first_arg_type: #GType of first argument of message, or %G_TYPE_NONE.
  * @...: %G_TYPE_NONE -terminated list of argument #GType's
  * 
- * Registers a new message type that the application supports. Example:
- * <informalexample><programlisting>
- * bonobo_application_register_message (app, "openURL", "Opens a new URL in the browser."
- *                                      " Parameters: url(string), open-in-new-window(boolean)",
- *                                      NULL, G_TYPE_NONE, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_NONE);
- * </programlisting></informalexample>
+ * Registers a new message type that the application supports.
  **/
 void
 bonobo_application_register_message (BonoboApplication *app,
